1. Introduction — Oncilla 0.1.0 documentation

# 1. Introduction

Oncilla is the documentation building helper package of Oncilla, Color, Manager, Umbra, sIBL_GUI and sIBL_Reporter.

With a single monolithic manual / help reStructuredText file used as input, an html manual file and the complete Sphinx documentation will be generated:

- Source manual reStructuredText file example
- Output manual html file example
- Output sphinx documentation example